SortAlgorithm

Enum SortAlgorithm 

pub enum SortAlgorithm {
    Auto,
    Comparison,
    Radix,
}
Sort algorithm selection for argsort operations

Variants



Auto

Automatically select the best algorithm for the data type.

When config.stable = true, this falls back to comparison sort which preserves relative order of equal elements. When stable = false, radix sort may be selected for eligible types.



Comparison

Standard comparison sort, O(n log n).

Respects config.stable: when true, uses a stable sort that preserves relative order of equal elements; when false, uses an unstable sort.



Radix

LSD radix sort for integers, O(n*k).

Always unstable — the config.stable flag is ignored when this algorithm is explicitly selected.