pub fn scale_vec(
n: i32,
alpha: f64,
x: &mut [f64],
incx: i32,
null_mask: Option<&Bitmask>,
null_count: Option<usize>,
) -> Result<(), KernelError>Expand description
In-place vector scaling: x ← α·x
This is the version for a matrix in a flat strided buffer, and therefore tackles incx (“increment x”) the gap between values.
Multiplies each element of the input vector x by the scalar alpha.
Equivalent to x[i] ← alpha * x[i] for all valid i.